# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.system_agent import SystemAgent  # noqa: F401,E501
from demisto_client.demisto_api.models.terminal_options import TerminalOptions  # noqa: F401,E501


class System(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent': 'SystemAgent',
        'arch': 'str',
        'ciphers': 'list[str]',
        'credentials': 'str',
        'engine_id': 'str',
        'host': 'str',
        'integrationinstanceid': 'str',
        'issharedagent': 'bool',
        'name': 'str',
        'os': 'str',
        'password': 'str',
        'smb': 'int',
        'smbport': 'int',
        'sshkey': 'str',
        'sshport': 'int',
        'terminal_options': 'TerminalOptions',
        'user': 'str',
        'workgroup': 'str'
    }

    attribute_map = {
        'agent': 'agent',
        'arch': 'arch',
        'ciphers': 'ciphers',
        'credentials': 'credentials',
        'engine_id': 'engineId',
        'host': 'host',
        'integrationinstanceid': 'integrationinstanceid',
        'issharedagent': 'issharedagent',
        'name': 'name',
        'os': 'os',
        'password': 'password',
        'smb': 'smb',
        'smbport': 'smbport',
        'sshkey': 'sshkey',
        'sshport': 'sshport',
        'terminal_options': 'terminalOptions',
        'user': 'user',
        'workgroup': 'workgroup'
    }

    def __init__(self, agent=None, arch=None, ciphers=None, credentials=None, engine_id=None, host=None, integrationinstanceid=None, issharedagent=None, name=None, os=None, password=None, smb=None, smbport=None, sshkey=None, sshport=None, terminal_options=None, user=None, workgroup=None):  # noqa: E501
        """System - a model defined in Swagger"""  # noqa: E501

        self._agent = None
        self._arch = None
        self._ciphers = None
        self._credentials = None
        self._engine_id = None
        self._host = None
        self._integrationinstanceid = None
        self._issharedagent = None
        self._name = None
        self._os = None
        self._password = None
        self._smb = None
        self._smbport = None
        self._sshkey = None
        self._sshport = None
        self._terminal_options = None
        self._user = None
        self._workgroup = None
        self.discriminator = None

        if agent is not None:
            self.agent = agent
        if arch is not None:
            self.arch = arch
        if ciphers is not None:
            self.ciphers = ciphers
        if credentials is not None:
            self.credentials = credentials
        if engine_id is not None:
            self.engine_id = engine_id
        if host is not None:
            self.host = host
        if integrationinstanceid is not None:
            self.integrationinstanceid = integrationinstanceid
        if issharedagent is not None:
            self.issharedagent = issharedagent
        if name is not None:
            self.name = name
        if os is not None:
            self.os = os
        if password is not None:
            self.password = password
        if smb is not None:
            self.smb = smb
        if smbport is not None:
            self.smbport = smbport
        if sshkey is not None:
            self.sshkey = sshkey
        if sshport is not None:
            self.sshport = sshport
        if terminal_options is not None:
            self.terminal_options = terminal_options
        if user is not None:
            self.user = user
        if workgroup is not None:
            self.workgroup = workgroup

    @property
    def agent(self):
        """Gets the agent of this System.  # noqa: E501


        :return: The agent of this System.  # noqa: E501
        :rtype: SystemAgent
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """Sets the agent of this System.


        :param agent: The agent of this System.  # noqa: E501
        :type: SystemAgent
        """

        self._agent = agent

    @property
    def arch(self):
        """Gets the arch of this System.  # noqa: E501


        :return: The arch of this System.  # noqa: E501
        :rtype: str
        """
        return self._arch

    @arch.setter
    def arch(self, arch):
        """Sets the arch of this System.


        :param arch: The arch of this System.  # noqa: E501
        :type: str
        """

        self._arch = arch

    @property
    def ciphers(self):
        """Gets the ciphers of this System.  # noqa: E501


        :return: The ciphers of this System.  # noqa: E501
        :rtype: list[str]
        """
        return self._ciphers

    @ciphers.setter
    def ciphers(self, ciphers):
        """Sets the ciphers of this System.


        :param ciphers: The ciphers of this System.  # noqa: E501
        :type: list[str]
        """

        self._ciphers = ciphers

    @property
    def credentials(self):
        """Gets the credentials of this System.  # noqa: E501


        :return: The credentials of this System.  # noqa: E501
        :rtype: str
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this System.


        :param credentials: The credentials of this System.  # noqa: E501
        :type: str
        """

        self._credentials = credentials

    @property
    def engine_id(self):
        """Gets the engine_id of this System.  # noqa: E501


        :return: The engine_id of this System.  # noqa: E501
        :rtype: str
        """
        return self._engine_id

    @engine_id.setter
    def engine_id(self, engine_id):
        """Sets the engine_id of this System.


        :param engine_id: The engine_id of this System.  # noqa: E501
        :type: str
        """

        self._engine_id = engine_id

    @property
    def host(self):
        """Gets the host of this System.  # noqa: E501


        :return: The host of this System.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this System.


        :param host: The host of this System.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def integrationinstanceid(self):
        """Gets the integrationinstanceid of this System.  # noqa: E501


        :return: The integrationinstanceid of this System.  # noqa: E501
        :rtype: str
        """
        return self._integrationinstanceid

    @integrationinstanceid.setter
    def integrationinstanceid(self, integrationinstanceid):
        """Sets the integrationinstanceid of this System.


        :param integrationinstanceid: The integrationinstanceid of this System.  # noqa: E501
        :type: str
        """

        self._integrationinstanceid = integrationinstanceid

    @property
    def issharedagent(self):
        """Gets the issharedagent of this System.  # noqa: E501


        :return: The issharedagent of this System.  # noqa: E501
        :rtype: bool
        """
        return self._issharedagent

    @issharedagent.setter
    def issharedagent(self, issharedagent):
        """Sets the issharedagent of this System.


        :param issharedagent: The issharedagent of this System.  # noqa: E501
        :type: bool
        """

        self._issharedagent = issharedagent

    @property
    def name(self):
        """Gets the name of this System.  # noqa: E501


        :return: The name of this System.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this System.


        :param name: The name of this System.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def os(self):
        """Gets the os of this System.  # noqa: E501


        :return: The os of this System.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this System.


        :param os: The os of this System.  # noqa: E501
        :type: str
        """

        self._os = os

    @property
    def password(self):
        """Gets the password of this System.  # noqa: E501


        :return: The password of this System.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this System.


        :param password: The password of this System.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def smb(self):
        """Gets the smb of this System.  # noqa: E501


        :return: The smb of this System.  # noqa: E501
        :rtype: int
        """
        return self._smb

    @smb.setter
    def smb(self, smb):
        """Sets the smb of this System.


        :param smb: The smb of this System.  # noqa: E501
        :type: int
        """

        self._smb = smb

    @property
    def smbport(self):
        """Gets the smbport of this System.  # noqa: E501


        :return: The smbport of this System.  # noqa: E501
        :rtype: int
        """
        return self._smbport

    @smbport.setter
    def smbport(self, smbport):
        """Sets the smbport of this System.


        :param smbport: The smbport of this System.  # noqa: E501
        :type: int
        """

        self._smbport = smbport

    @property
    def sshkey(self):
        """Gets the sshkey of this System.  # noqa: E501


        :return: The sshkey of this System.  # noqa: E501
        :rtype: str
        """
        return self._sshkey

    @sshkey.setter
    def sshkey(self, sshkey):
        """Sets the sshkey of this System.


        :param sshkey: The sshkey of this System.  # noqa: E501
        :type: str
        """

        self._sshkey = sshkey

    @property
    def sshport(self):
        """Gets the sshport of this System.  # noqa: E501


        :return: The sshport of this System.  # noqa: E501
        :rtype: int
        """
        return self._sshport

    @sshport.setter
    def sshport(self, sshport):
        """Sets the sshport of this System.


        :param sshport: The sshport of this System.  # noqa: E501
        :type: int
        """

        self._sshport = sshport

    @property
    def terminal_options(self):
        """Gets the terminal_options of this System.  # noqa: E501


        :return: The terminal_options of this System.  # noqa: E501
        :rtype: TerminalOptions
        """
        return self._terminal_options

    @terminal_options.setter
    def terminal_options(self, terminal_options):
        """Sets the terminal_options of this System.


        :param terminal_options: The terminal_options of this System.  # noqa: E501
        :type: TerminalOptions
        """

        self._terminal_options = terminal_options

    @property
    def user(self):
        """Gets the user of this System.  # noqa: E501


        :return: The user of this System.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this System.


        :param user: The user of this System.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def workgroup(self):
        """Gets the workgroup of this System.  # noqa: E501


        :return: The workgroup of this System.  # noqa: E501
        :rtype: str
        """
        return self._workgroup

    @workgroup.setter
    def workgroup(self, workgroup):
        """Sets the workgroup of this System.


        :param workgroup: The workgroup of this System.  # noqa: E501
        :type: str
        """

        self._workgroup = workgroup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(System, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, System):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import copy
import logging
import multiprocessing
import sys
import urllib3

import six
from six.moves import http_client as httplib


class Configuration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Ref: https://github.com/swagger-api/swagger-codegen
    Do not edit the class manually.
    """

    _default = None

    def __init__(self):
        """Constructor"""
        if self._default:
            for key in self._default.__dict__.keys():
                self.__dict__[key] = copy.copy(self._default.__dict__[key])
            return

        # Default Base url
        self.host = "https://hostname:443"
        # Temp file folder for downloading files
        self.temp_folder_path = None

        # Authentication Settings
        # dict to store API key(s)
        self.api_key = {}
        # dict to store API prefix (e.g. Bearer)
        self.api_key_prefix = {}
        # Username for HTTP basic authentication
        self.username = ""
        # Password for HTTP basic authentication
        self.password = ""

        # Logging Settings
        self.logger = {}
        self.logger["package_logger"] = logging.getLogger("demisto_client.demisto_api")
        self.logger["urllib3_logger"] = logging.getLogger("urllib3")
        # Log format
        self.logger_format = '%(asctime)s %(levelname)s %(message)s'
        # Log stream handler
        self.logger_stream_handler = None
        # Log file handler
        self.logger_file_handler = None
        # Debug file location
        self.logger_file = None
        # Debug switch
        self.debug = False

        # SSL/TLS verification
        # Set this to false to skip verifying SSL certificate when calling API
        # from https server.
        self.verify_ssl = True
        # Set this to customize the certificate file to verify the peer.
        self.ssl_ca_cert = None
        # client certificate file
        self.cert_file = None
        # client key file
        self.key_file = None
        # Set this to True/False to enable/disable SSL hostname verification.
        self.assert_hostname = None

        # urllib3 connection pool's maximum number of connections saved
        # per pool. urllib3 uses 1 connection as default value, but this is
        # not the best value when you are making a lot of possibly parallel
        # requests to the same host, which is often the case here.
        # cpu_count * 5 is used as default value to increase performance.
        self.connection_pool_maxsize = multiprocessing.cpu_count() * 5

        # Proxy URL
        self.proxy = None
        # Safe chars for path_param
        self.safe_chars_for_path_param = ''

    @classmethod
    def set_default(cls, default):
        cls._default = default

    @property
    def logger_file(self):
        """The logger file.

        If the logger_file is None, then add stream handler and remove file
        handler. Otherwise, add file handler and remove stream handler.

        :param value: The logger_file path.
        :type: str
        """
        return self.__logger_file

    @logger_file.setter
    def logger_file(self, value):
        """The logger file.

        If the logger_file is None, then add stream handler and remove file
        handler. Otherwise, add file handler and remove stream handler.

        :param value: The logger_file path.
        :type: str
        """
        self.__logger_file = value
        if self.__logger_file:
            # If set logging file,
            # then add file handler and remove stream handler.
            self.logger_file_handler = logging.FileHandler(self.__logger_file)
            self.logger_file_handler.setFormatter(self.logger_formatter)
            for _, logger in six.iteritems(self.logger):
                logger.addHandler(self.logger_file_handler)
                if self.logger_stream_handler:
                    logger.removeHandler(self.logger_stream_handler)
        else:
            # If not set logging file,
            # then add stream handler and remove file handler.
            self.logger_stream_handler = logging.StreamHandler()
            self.logger_stream_handler.setFormatter(self.logger_formatter)
            for _, logger in six.iteritems(self.logger):
                logger.addHandler(self.logger_stream_handler)
                if self.logger_file_handler:
                    logger.removeHandler(self.logger_file_handler)

    @property
    def debug(self):
        """Debug status

        :param value: The debug status, True or False.
        :type: bool
        """
        return self.__debug

    @debug.setter
    def debug(self, value):
        """Debug status

        :param value: The debug status, True or False.
        :type: bool
        """
        self.__debug = value
        if self.__debug:
            # if debug status is True, turn on debug logging
            for _, logger in six.iteritems(self.logger):
                logger.setLevel(logging.DEBUG)
            # turn on httplib debug
            httplib.HTTPConnection.debuglevel = 1
        else:
            # if debug status is False, turn off debug logging,
            # setting log level to default `logging.WARNING`
            for _, logger in six.iteritems(self.logger):
                logger.setLevel(logging.WARNING)
            # turn off httplib debug
            httplib.HTTPConnection.debuglevel = 0

    @property
    def logger_format(self):
        """The logger format.

        The logger_formatter will be updated when sets logger_format.

        :param value: The format string.
        :type: str
        """
        return self.__logger_format

    @logger_format.setter
    def logger_format(self, value):
        """The logger format.

        The logger_formatter will be updated when sets logger_format.

        :param value: The format string.
        :type: str
        """
        self.__logger_format = value
        self.logger_formatter = logging.Formatter(self.__logger_format)

    def get_api_key_with_prefix(self, identifier):
        """Gets API key (with prefix if set).

        :param identifier: The identifier of apiKey.
        :return: The token for api key authentication.
        """
        if (self.api_key.get(identifier) and
                self.api_key_prefix.get(identifier)):
            return self.api_key_prefix[identifier] + ' ' + self.api_key[identifier]  # noqa: E501
        elif self.api_key.get(identifier):
            return self.api_key[identifier]

    def get_basic_auth_token(self):
        """Gets HTTP basic authentication header (string).

        :return: The token for basic HTTP authentication.
        """
        return urllib3.util.make_headers(
            basic_auth=self.username + ':' + self.password
        ).get('authorization')

    def auth_settings(self):
        """Gets Auth Settings dict for api client.

        :return: The Auth Settings information dict.
        """
        return {
            'api_key':
                {
                    'type': 'api_key',
                    'in': 'header',
                    'key': 'Authorization',
                    'value': self.get_api_key_with_prefix('Authorization')
                },
            'csrf_token':
                {
                    'type': 'api_key',
                    'in': 'header',
                    'key': 'X-XSRF-TOKEN',
                    'value': self.get_api_key_with_prefix('X-XSRF-TOKEN')
                },
            'x-xdr-auth-id':
                {
                    'type': 'api_key',
                    'in': 'header',
                    'key': 'x-xdr-auth-id',
                    'value': self.get_api_key_with_prefix('x-xdr-auth-id')
                },

        }

    def to_debug_report(self):
        """Gets the essential information for debugging.

        :return: The report for debugging.
        """
        return "Python SDK Debug Report:\n"\
               "OS: {env}\n"\
               "Python Version: {pyversion}\n"\
               "Version of the API: 2.0.0\n"\
               "SDK Package Version: 2.0.0".\
               format(env=sys.platform, pyversion=sys.version)



import demisto_client.demisto_api
from demisto_client.demisto_api.rest import ApiException
from datetime import datetime
import tempfile
import os
import time

api_key = None  # set to your 'YOUR_API_KEY' or set environment variable: DEMISTO_API_KEY
base_url = None  # set to your 'http://DEMISTO_HOST' or set environment variable: DEMISTO_BASE_URL

api_instance = demisto_client.configure(base_url=base_url, api_key=api_key, debug=True)
create_incident_request = demisto_client.demisto_api.CreateIncidentRequest()

create_incident_request.name = 'Sample Malware Incident: {}'.format(datetime.now())
create_incident_request.type = 'Malware'
create_incident_request.owner = 'admin'
create_incident_request.severity = 1
create_incident_request.occurred = datetime.now()
create_incident_request.create_investigation = False  # we set to false as we still neeed to upload a file
create_incident_request.playbook_id = 'malware_investigation-_generic'
# If you want to set source_brand and source_instance it is required to set the `Instance` label
create_incident_request.labels = [demisto_client.demisto_api.Label('Instance', 'Demisto Py Client')]
create_incident_request.source_brand = 'API'
create_incident_request.source_instance = 'Demisto Py Client'
create_incident_request.custom_fields = {
    'src': '1.1.1.1',
    'dest': '192.168.1.1',
    'malwarefamily': 'Trojan.Generic',
    'filehash': '142b638c6a60b60c7f9928da4fb85a5a8e1422a9ffdc9ee49e17e56ccca9cf6e',
    'vendorproduct': 'Secure Product',
}

tf = None
try:
    api_response = api_instance.create_incident(create_incident_request=create_incident_request)
    print("Create incident response: {}".format(api_response))
    tf = tempfile.NamedTemporaryFile(delete=False)
    tf.write(b'Test data representing an uploaded file')
    tf.close()
    # note that this is a form post. `last` needs to be true/false string and not boolean
    res_upload = api_instance.incident_file_upload(id=api_response.id, file=tf.name, file_name="test-report.txt", 
                                                   file_comment='Test report file', last='true')
    print("Upload file to incident response: {}".format(res_upload))
    # the uploaded file will be the 3rd entry. Let's download it
    print('sleeping 10 seconds before download....')
    time.sleep(10)  # sleep a few seconds to allow server to fully index
    res_download = api_instance.download_file('3@{}'.format(api_response.id))
    print("Download file result: {}".format(res_download))
except ApiException as e:
    print("Exception when calling DefaultApi->create_incident: %s\n" % e)
finally:
    if tf:
        os.unlink(tf.name)



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.task_type import TaskType  # noqa: F401,E501


class Task(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brand': 'str',
        'cloned_from': 'str',
        'comment': 'str',
        'conditions': 'list[str]',
        'description': 'str',
        'id': 'str',
        'is_command': 'bool',
        'is_locked': 'bool',
        'is_system_task': 'bool',
        'is_title_task': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'playbook_id': 'str',
        'script_id': 'str',
        'sort_values': 'list[str]',
        'tags': 'list[str]',
        'type': 'TaskType',
        'version': 'int'
    }

    attribute_map = {
        'brand': 'brand',
        'cloned_from': 'clonedFrom',
        'comment': 'comment',
        'conditions': 'conditions',
        'description': 'description',
        'id': 'id',
        'is_command': 'isCommand',
        'is_locked': 'isLocked',
        'is_system_task': 'isSystemTask',
        'is_title_task': 'isTitleTask',
        'modified': 'modified',
        'name': 'name',
        'playbook_id': 'playbookId',
        'script_id': 'scriptId',
        'sort_values': 'sortValues',
        'tags': 'tags',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, brand=None, cloned_from=None, comment=None, conditions=None, description=None, id=None, is_command=None, is_locked=None, is_system_task=None, is_title_task=None, modified=None, name=None, playbook_id=None, script_id=None, sort_values=None, tags=None, type=None, version=None):  # noqa: E501
        """Task - a model defined in Swagger"""  # noqa: E501

        self._brand = None
        self._cloned_from = None
        self._comment = None
        self._conditions = None
        self._description = None
        self._id = None
        self._is_command = None
        self._is_locked = None
        self._is_system_task = None
        self._is_title_task = None
        self._modified = None
        self._name = None
        self._playbook_id = None
        self._script_id = None
        self._sort_values = None
        self._tags = None
        self._type = None
        self._version = None
        self.discriminator = None

        if brand is not None:
            self.brand = brand
        if cloned_from is not None:
            self.cloned_from = cloned_from
        if comment is not None:
            self.comment = comment
        if conditions is not None:
            self.conditions = conditions
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if is_command is not None:
            self.is_command = is_command
        if is_locked is not None:
            self.is_locked = is_locked
        if is_system_task is not None:
            self.is_system_task = is_system_task
        if is_title_task is not None:
            self.is_title_task = is_title_task
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if playbook_id is not None:
            self.playbook_id = playbook_id
        if script_id is not None:
            self.script_id = script_id
        if sort_values is not None:
            self.sort_values = sort_values
        if tags is not None:
            self.tags = tags
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def brand(self):
        """Gets the brand of this Task.  # noqa: E501


        :return: The brand of this Task.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this Task.


        :param brand: The brand of this Task.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def cloned_from(self):
        """Gets the cloned_from of this Task.  # noqa: E501


        :return: The cloned_from of this Task.  # noqa: E501
        :rtype: str
        """
        return self._cloned_from

    @cloned_from.setter
    def cloned_from(self, cloned_from):
        """Sets the cloned_from of this Task.


        :param cloned_from: The cloned_from of this Task.  # noqa: E501
        :type: str
        """

        self._cloned_from = cloned_from

    @property
    def comment(self):
        """Gets the comment of this Task.  # noqa: E501


        :return: The comment of this Task.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Task.


        :param comment: The comment of this Task.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def conditions(self):
        """Gets the conditions of this Task.  # noqa: E501


        :return: The conditions of this Task.  # noqa: E501
        :rtype: list[str]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this Task.


        :param conditions: The conditions of this Task.  # noqa: E501
        :type: list[str]
        """

        self._conditions = conditions

    @property
    def description(self):
        """Gets the description of this Task.  # noqa: E501


        :return: The description of this Task.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Task.


        :param description: The description of this Task.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this Task.  # noqa: E501


        :return: The id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Task.


        :param id: The id of this Task.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_command(self):
        """Gets the is_command of this Task.  # noqa: E501


        :return: The is_command of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._is_command

    @is_command.setter
    def is_command(self, is_command):
        """Sets the is_command of this Task.


        :param is_command: The is_command of this Task.  # noqa: E501
        :type: bool
        """

        self._is_command = is_command

    @property
    def is_locked(self):
        """Gets the is_locked of this Task.  # noqa: E501


        :return: The is_locked of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._is_locked

    @is_locked.setter
    def is_locked(self, is_locked):
        """Sets the is_locked of this Task.


        :param is_locked: The is_locked of this Task.  # noqa: E501
        :type: bool
        """

        self._is_locked = is_locked

    @property
    def is_system_task(self):
        """Gets the is_system_task of this Task.  # noqa: E501


        :return: The is_system_task of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._is_system_task

    @is_system_task.setter
    def is_system_task(self, is_system_task):
        """Sets the is_system_task of this Task.


        :param is_system_task: The is_system_task of this Task.  # noqa: E501
        :type: bool
        """

        self._is_system_task = is_system_task

    @property
    def is_title_task(self):
        """Gets the is_title_task of this Task.  # noqa: E501


        :return: The is_title_task of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._is_title_task

    @is_title_task.setter
    def is_title_task(self, is_title_task):
        """Sets the is_title_task of this Task.


        :param is_title_task: The is_title_task of this Task.  # noqa: E501
        :type: bool
        """

        self._is_title_task = is_title_task

    @property
    def modified(self):
        """Gets the modified of this Task.  # noqa: E501


        :return: The modified of this Task.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Task.


        :param modified: The modified of this Task.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Task.  # noqa: E501


        :return: The name of this Task.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Task.


        :param name: The name of this Task.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def playbook_id(self):
        """Gets the playbook_id of this Task.  # noqa: E501


        :return: The playbook_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._playbook_id

    @playbook_id.setter
    def playbook_id(self, playbook_id):
        """Sets the playbook_id of this Task.


        :param playbook_id: The playbook_id of this Task.  # noqa: E501
        :type: str
        """

        self._playbook_id = playbook_id

    @property
    def script_id(self):
        """Gets the script_id of this Task.  # noqa: E501


        :return: The script_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """Sets the script_id of this Task.


        :param script_id: The script_id of this Task.  # noqa: E501
        :type: str
        """

        self._script_id = script_id

    @property
    def sort_values(self):
        """Gets the sort_values of this Task.  # noqa: E501


        :return: The sort_values of this Task.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Task.


        :param sort_values: The sort_values of this Task.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def tags(self):
        """Gets the tags of this Task.  # noqa: E501


        :return: The tags of this Task.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Task.


        :param tags: The tags of this Task.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this Task.  # noqa: E501


        :return: The type of this Task.  # noqa: E501
        :rtype: TaskType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Task.


        :param type: The type of this Task.  # noqa: E501
        :type: TaskType
        """

        self._type = type

    @property
    def version(self):
        """Gets the version of this Task.  # noqa: E501


        :return: The version of this Task.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Task.


        :param version: The version of this Task.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Task, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Task):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.investigation_status import InvestigationStatus  # noqa: F401,E501
from demisto_client.demisto_api.models.investigation_type import InvestigationType  # noqa: F401,E501
from demisto_client.demisto_api.models.run_status import RunStatus  # noqa: F401,E501
from demisto_client.demisto_api.models.system import System  # noqa: F401,E501


class Investigation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shard_id': 'int',
        'category': 'str',
        'child_investigations': 'list[str]',
        'closed': 'datetime',
        'closing_user_id': 'str',
        'created': 'datetime',
        'creating_user_id': 'str',
        'details': 'str',
        'entitlements': 'list[str]',
        'entry_users': 'list[str]',
        'has_role': 'bool',
        'id': 'str',
        'is_child_investigation': 'bool',
        'last_open': 'datetime',
        'mirror_auto_close': 'dict(str, bool)',
        'mirror_types': 'dict(str, str)',
        'modified': 'datetime',
        'name': 'str',
        'open_duration': 'int',
        'parent_investigation': 'str',
        'persistent_entitlements': 'dict(str, str)',
        'previous_roles': 'list[str]',
        'raw_category': 'str',
        'reason': 'dict(str, str)',
        'roles': 'list[str]',
        'run_status': 'RunStatus',
        'slack_mirror_auto_close': 'bool',
        'slack_mirror_type': 'str',
        'sort_values': 'list[str]',
        'status': 'InvestigationStatus',
        'systems': 'list[System]',
        'tags': 'list[str]',
        'type': 'InvestigationType',
        'users': 'list[str]',
        'version': 'int'
    }

    attribute_map = {
        'shard_id': 'ShardID',
        'category': 'category',
        'child_investigations': 'childInvestigations',
        'closed': 'closed',
        'closing_user_id': 'closingUserId',
        'created': 'created',
        'creating_user_id': 'creatingUserId',
        'details': 'details',
        'entitlements': 'entitlements',
        'entry_users': 'entryUsers',
        'has_role': 'hasRole',
        'id': 'id',
        'is_child_investigation': 'isChildInvestigation',
        'last_open': 'lastOpen',
        'mirror_auto_close': 'mirrorAutoClose',
        'mirror_types': 'mirrorTypes',
        'modified': 'modified',
        'name': 'name',
        'open_duration': 'openDuration',
        'parent_investigation': 'parentInvestigation',
        'persistent_entitlements': 'persistentEntitlements',
        'previous_roles': 'previousRoles',
        'raw_category': 'rawCategory',
        'reason': 'reason',
        'roles': 'roles',
        'run_status': 'runStatus',
        'slack_mirror_auto_close': 'slackMirrorAutoClose',
        'slack_mirror_type': 'slackMirrorType',
        'sort_values': 'sortValues',
        'status': 'status',
        'systems': 'systems',
        'tags': 'tags',
        'type': 'type',
        'users': 'users',
        'version': 'version'
    }

    def __init__(self, shard_id=None, category=None, child_investigations=None, closed=None, closing_user_id=None, created=None, creating_user_id=None, details=None, entitlements=None, entry_users=None, has_role=None, id=None, is_child_investigation=None, last_open=None, mirror_auto_close=None, mirror_types=None, modified=None, name=None, open_duration=None, parent_investigation=None, persistent_entitlements=None, previous_roles=None, raw_category=None, reason=None, roles=None, run_status=None, slack_mirror_auto_close=None, slack_mirror_type=None, sort_values=None, status=None, systems=None, tags=None, type=None, users=None, version=None):  # noqa: E501
        """Investigation - a model defined in Swagger"""  # noqa: E501

        self._shard_id = None
        self._category = None
        self._child_investigations = None
        self._closed = None
        self._closing_user_id = None
        self._created = None
        self._creating_user_id = None
        self._details = None
        self._entitlements = None
        self._entry_users = None
        self._has_role = None
        self._id = None
        self._is_child_investigation = None
        self._last_open = None
        self._mirror_auto_close = None
        self._mirror_types = None
        self._modified = None
        self._name = None
        self._open_duration = None
        self._parent_investigation = None
        self._persistent_entitlements = None
        self._previous_roles = None
        self._raw_category = None
        self._reason = None
        self._roles = None
        self._run_status = None
        self._slack_mirror_auto_close = None
        self._slack_mirror_type = None
        self._sort_values = None
        self._status = None
        self._systems = None
        self._tags = None
        self._type = None
        self._users = None
        self._version = None
        self.discriminator = None

        if shard_id is not None:
            self.shard_id = shard_id
        if category is not None:
            self.category = category
        if child_investigations is not None:
            self.child_investigations = child_investigations
        if closed is not None:
            self.closed = closed
        if closing_user_id is not None:
            self.closing_user_id = closing_user_id
        if created is not None:
            self.created = created
        if creating_user_id is not None:
            self.creating_user_id = creating_user_id
        if details is not None:
            self.details = details
        if entitlements is not None:
            self.entitlements = entitlements
        if entry_users is not None:
            self.entry_users = entry_users
        if has_role is not None:
            self.has_role = has_role
        if id is not None:
            self.id = id
        if is_child_investigation is not None:
            self.is_child_investigation = is_child_investigation
        if last_open is not None:
            self.last_open = last_open
        if mirror_auto_close is not None:
            self.mirror_auto_close = mirror_auto_close
        if mirror_types is not None:
            self.mirror_types = mirror_types
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if open_duration is not None:
            self.open_duration = open_duration
        if parent_investigation is not None:
            self.parent_investigation = parent_investigation
        if persistent_entitlements is not None:
            self.persistent_entitlements = persistent_entitlements
        if previous_roles is not None:
            self.previous_roles = previous_roles
        if raw_category is not None:
            self.raw_category = raw_category
        if reason is not None:
            self.reason = reason
        if roles is not None:
            self.roles = roles
        if run_status is not None:
            self.run_status = run_status
        if slack_mirror_auto_close is not None:
            self.slack_mirror_auto_close = slack_mirror_auto_close
        if slack_mirror_type is not None:
            self.slack_mirror_type = slack_mirror_type
        if sort_values is not None:
            self.sort_values = sort_values
        if status is not None:
            self.status = status
        if systems is not None:
            self.systems = systems
        if tags is not None:
            self.tags = tags
        if type is not None:
            self.type = type
        if users is not None:
            self.users = users
        if version is not None:
            self.version = version

    @property
    def shard_id(self):
        """Gets the shard_id of this Investigation.  # noqa: E501


        :return: The shard_id of this Investigation.  # noqa: E501
        :rtype: int
        """
        return self._shard_id

    @shard_id.setter
    def shard_id(self, shard_id):
        """Sets the shard_id of this Investigation.


        :param shard_id: The shard_id of this Investigation.  # noqa: E501
        :type: int
        """

        self._shard_id = shard_id

    @property
    def category(self):
        """Gets the category of this Investigation.  # noqa: E501

        Category of the investigation  # noqa: E501

        :return: The category of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Investigation.

        Category of the investigation  # noqa: E501

        :param category: The category of this Investigation.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def child_investigations(self):
        """Gets the child_investigations of this Investigation.  # noqa: E501

        ChildInvestigations id's  # noqa: E501

        :return: The child_investigations of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._child_investigations

    @child_investigations.setter
    def child_investigations(self, child_investigations):
        """Sets the child_investigations of this Investigation.

        ChildInvestigations id's  # noqa: E501

        :param child_investigations: The child_investigations of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._child_investigations = child_investigations

    @property
    def closed(self):
        """Gets the closed of this Investigation.  # noqa: E501

        When was this closed  # noqa: E501

        :return: The closed of this Investigation.  # noqa: E501
        :rtype: datetime
        """
        return self._closed

    @closed.setter
    def closed(self, closed):
        """Sets the closed of this Investigation.

        When was this closed  # noqa: E501

        :param closed: The closed of this Investigation.  # noqa: E501
        :type: datetime
        """

        self._closed = closed

    @property
    def closing_user_id(self):
        """Gets the closing_user_id of this Investigation.  # noqa: E501

        The user ID that closed this investigation  # noqa: E501

        :return: The closing_user_id of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._closing_user_id

    @closing_user_id.setter
    def closing_user_id(self, closing_user_id):
        """Sets the closing_user_id of this Investigation.

        The user ID that closed this investigation  # noqa: E501

        :param closing_user_id: The closing_user_id of this Investigation.  # noqa: E501
        :type: str
        """

        self._closing_user_id = closing_user_id

    @property
    def created(self):
        """Gets the created of this Investigation.  # noqa: E501

        When was this created  # noqa: E501

        :return: The created of this Investigation.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Investigation.

        When was this created  # noqa: E501

        :param created: The created of this Investigation.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def creating_user_id(self):
        """Gets the creating_user_id of this Investigation.  # noqa: E501

        The user ID that created this investigation  # noqa: E501

        :return: The creating_user_id of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._creating_user_id

    @creating_user_id.setter
    def creating_user_id(self, creating_user_id):
        """Sets the creating_user_id of this Investigation.

        The user ID that created this investigation  # noqa: E501

        :param creating_user_id: The creating_user_id of this Investigation.  # noqa: E501
        :type: str
        """

        self._creating_user_id = creating_user_id

    @property
    def details(self):
        """Gets the details of this Investigation.  # noqa: E501

        User defined free text details  # noqa: E501

        :return: The details of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Investigation.

        User defined free text details  # noqa: E501

        :param details: The details of this Investigation.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def entitlements(self):
        """Gets the entitlements of this Investigation.  # noqa: E501

        One time entitlements  # noqa: E501

        :return: The entitlements of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._entitlements

    @entitlements.setter
    def entitlements(self, entitlements):
        """Sets the entitlements of this Investigation.

        One time entitlements  # noqa: E501

        :param entitlements: The entitlements of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._entitlements = entitlements

    @property
    def entry_users(self):
        """Gets the entry_users of this Investigation.  # noqa: E501

        EntryUsers  # noqa: E501

        :return: The entry_users of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._entry_users

    @entry_users.setter
    def entry_users(self, entry_users):
        """Sets the entry_users of this Investigation.

        EntryUsers  # noqa: E501

        :param entry_users: The entry_users of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._entry_users = entry_users

    @property
    def has_role(self):
        """Gets the has_role of this Investigation.  # noqa: E501

        Internal field to make queries on role faster  # noqa: E501

        :return: The has_role of this Investigation.  # noqa: E501
        :rtype: bool
        """
        return self._has_role

    @has_role.setter
    def has_role(self, has_role):
        """Sets the has_role of this Investigation.

        Internal field to make queries on role faster  # noqa: E501

        :param has_role: The has_role of this Investigation.  # noqa: E501
        :type: bool
        """

        self._has_role = has_role

    @property
    def id(self):
        """Gets the id of this Investigation.  # noqa: E501


        :return: The id of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Investigation.


        :param id: The id of this Investigation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_child_investigation(self):
        """Gets the is_child_investigation of this Investigation.  # noqa: E501

        IsChildInvestigation  # noqa: E501

        :return: The is_child_investigation of this Investigation.  # noqa: E501
        :rtype: bool
        """
        return self._is_child_investigation

    @is_child_investigation.setter
    def is_child_investigation(self, is_child_investigation):
        """Sets the is_child_investigation of this Investigation.

        IsChildInvestigation  # noqa: E501

        :param is_child_investigation: The is_child_investigation of this Investigation.  # noqa: E501
        :type: bool
        """

        self._is_child_investigation = is_child_investigation

    @property
    def last_open(self):
        """Gets the last_open of this Investigation.  # noqa: E501


        :return: The last_open of this Investigation.  # noqa: E501
        :rtype: datetime
        """
        return self._last_open

    @last_open.setter
    def last_open(self, last_open):
        """Sets the last_open of this Investigation.


        :param last_open: The last_open of this Investigation.  # noqa: E501
        :type: datetime
        """

        self._last_open = last_open

    @property
    def mirror_auto_close(self):
        """Gets the mirror_auto_close of this Investigation.  # noqa: E501

        MirrorAutoClose will tell us to close the Chat Module channel if we close investigation  # noqa: E501

        :return: The mirror_auto_close of this Investigation.  # noqa: E501
        :rtype: dict(str, bool)
        """
        return self._mirror_auto_close

    @mirror_auto_close.setter
    def mirror_auto_close(self, mirror_auto_close):
        """Sets the mirror_auto_close of this Investigation.

        MirrorAutoClose will tell us to close the Chat Module channel if we close investigation  # noqa: E501

        :param mirror_auto_close: The mirror_auto_close of this Investigation.  # noqa: E501
        :type: dict(str, bool)
        """

        self._mirror_auto_close = mirror_auto_close

    @property
    def mirror_types(self):
        """Gets the mirror_types of this Investigation.  # noqa: E501

        MirrorTypes holds info about mirror direction and message type to be mirrored message type can be either 'all' or 'chat' direction can be either 'FromDemisto', 'ToDemisto' or 'Both' if this investigation is mirrored  # noqa: E501

        :return: The mirror_types of this Investigation.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._mirror_types

    @mirror_types.setter
    def mirror_types(self, mirror_types):
        """Sets the mirror_types of this Investigation.

        MirrorTypes holds info about mirror direction and message type to be mirrored message type can be either 'all' or 'chat' direction can be either 'FromDemisto', 'ToDemisto' or 'Both' if this investigation is mirrored  # noqa: E501

        :param mirror_types: The mirror_types of this Investigation.  # noqa: E501
        :type: dict(str, str)
        """

        self._mirror_types = mirror_types

    @property
    def modified(self):
        """Gets the modified of this Investigation.  # noqa: E501


        :return: The modified of this Investigation.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Investigation.


        :param modified: The modified of this Investigation.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Investigation.  # noqa: E501

        The name of the investigation, which is unique to the project  # noqa: E501

        :return: The name of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Investigation.

        The name of the investigation, which is unique to the project  # noqa: E501

        :param name: The name of this Investigation.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def open_duration(self):
        """Gets the open_duration of this Investigation.  # noqa: E501

        Duration from open to close time  # noqa: E501

        :return: The open_duration of this Investigation.  # noqa: E501
        :rtype: int
        """
        return self._open_duration

    @open_duration.setter
    def open_duration(self, open_duration):
        """Sets the open_duration of this Investigation.

        Duration from open to close time  # noqa: E501

        :param open_duration: The open_duration of this Investigation.  # noqa: E501
        :type: int
        """

        self._open_duration = open_duration

    @property
    def parent_investigation(self):
        """Gets the parent_investigation of this Investigation.  # noqa: E501

        ParentInvestigation - parent id, in case this is a child investigation of another investigation  # noqa: E501

        :return: The parent_investigation of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._parent_investigation

    @parent_investigation.setter
    def parent_investigation(self, parent_investigation):
        """Sets the parent_investigation of this Investigation.

        ParentInvestigation - parent id, in case this is a child investigation of another investigation  # noqa: E501

        :param parent_investigation: The parent_investigation of this Investigation.  # noqa: E501
        :type: str
        """

        self._parent_investigation = parent_investigation

    @property
    def persistent_entitlements(self):
        """Gets the persistent_entitlements of this Investigation.  # noqa: E501

        Persistent entitlement per tag. Empty tag will also return an entitlement  # noqa: E501

        :return: The persistent_entitlements of this Investigation.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._persistent_entitlements

    @persistent_entitlements.setter
    def persistent_entitlements(self, persistent_entitlements):
        """Sets the persistent_entitlements of this Investigation.

        Persistent entitlement per tag. Empty tag will also return an entitlement  # noqa: E501

        :param persistent_entitlements: The persistent_entitlements of this Investigation.  # noqa: E501
        :type: dict(str, str)
        """

        self._persistent_entitlements = persistent_entitlements

    @property
    def previous_roles(self):
        """Gets the previous_roles of this Investigation.  # noqa: E501

        PreviousRoleName - do not change this field manually  # noqa: E501

        :return: The previous_roles of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._previous_roles

    @previous_roles.setter
    def previous_roles(self, previous_roles):
        """Sets the previous_roles of this Investigation.

        PreviousRoleName - do not change this field manually  # noqa: E501

        :param previous_roles: The previous_roles of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._previous_roles = previous_roles

    @property
    def raw_category(self):
        """Gets the raw_category of this Investigation.  # noqa: E501


        :return: The raw_category of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._raw_category

    @raw_category.setter
    def raw_category(self, raw_category):
        """Sets the raw_category of this Investigation.


        :param raw_category: The raw_category of this Investigation.  # noqa: E501
        :type: str
        """

        self._raw_category = raw_category

    @property
    def reason(self):
        """Gets the reason of this Investigation.  # noqa: E501

        The reason for the status (resolve)  # noqa: E501

        :return: The reason of this Investigation.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this Investigation.

        The reason for the status (resolve)  # noqa: E501

        :param reason: The reason of this Investigation.  # noqa: E501
        :type: dict(str, str)
        """

        self._reason = reason

    @property
    def roles(self):
        """Gets the roles of this Investigation.  # noqa: E501

        The role assigned to this investigation  # noqa: E501

        :return: The roles of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Investigation.

        The role assigned to this investigation  # noqa: E501

        :param roles: The roles of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def run_status(self):
        """Gets the run_status of this Investigation.  # noqa: E501


        :return: The run_status of this Investigation.  # noqa: E501
        :rtype: RunStatus
        """
        return self._run_status

    @run_status.setter
    def run_status(self, run_status):
        """Sets the run_status of this Investigation.


        :param run_status: The run_status of this Investigation.  # noqa: E501
        :type: RunStatus
        """

        self._run_status = run_status

    @property
    def slack_mirror_auto_close(self):
        """Gets the slack_mirror_auto_close of this Investigation.  # noqa: E501

        DEPRECATED - DeprecatedSlackMirrorAutoClose will tell us to close the Slack channel if we close investigation  # noqa: E501

        :return: The slack_mirror_auto_close of this Investigation.  # noqa: E501
        :rtype: bool
        """
        return self._slack_mirror_auto_close

    @slack_mirror_auto_close.setter
    def slack_mirror_auto_close(self, slack_mirror_auto_close):
        """Sets the slack_mirror_auto_close of this Investigation.

        DEPRECATED - DeprecatedSlackMirrorAutoClose will tell us to close the Slack channel if we close investigation  # noqa: E501

        :param slack_mirror_auto_close: The slack_mirror_auto_close of this Investigation.  # noqa: E501
        :type: bool
        """

        self._slack_mirror_auto_close = slack_mirror_auto_close

    @property
    def slack_mirror_type(self):
        """Gets the slack_mirror_type of this Investigation.  # noqa: E501

        DEPRECATED - DeprecatedSlackMirrorType holds info about mirror direction and message type to be mirror message type can be either 'all' or 'chat' direction can be either 'demisto2Slack', 'slack2Demisto' or 'both' if this investigation is mirrored to Slack  # noqa: E501

        :return: The slack_mirror_type of this Investigation.  # noqa: E501
        :rtype: str
        """
        return self._slack_mirror_type

    @slack_mirror_type.setter
    def slack_mirror_type(self, slack_mirror_type):
        """Sets the slack_mirror_type of this Investigation.

        DEPRECATED - DeprecatedSlackMirrorType holds info about mirror direction and message type to be mirror message type can be either 'all' or 'chat' direction can be either 'demisto2Slack', 'slack2Demisto' or 'both' if this investigation is mirrored to Slack  # noqa: E501

        :param slack_mirror_type: The slack_mirror_type of this Investigation.  # noqa: E501
        :type: str
        """

        self._slack_mirror_type = slack_mirror_type

    @property
    def sort_values(self):
        """Gets the sort_values of this Investigation.  # noqa: E501


        :return: The sort_values of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Investigation.


        :param sort_values: The sort_values of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def status(self):
        """Gets the status of this Investigation.  # noqa: E501


        :return: The status of this Investigation.  # noqa: E501
        :rtype: InvestigationStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Investigation.


        :param status: The status of this Investigation.  # noqa: E501
        :type: InvestigationStatus
        """

        self._status = status

    @property
    def systems(self):
        """Gets the systems of this Investigation.  # noqa: E501

        The systems involved  # noqa: E501

        :return: The systems of this Investigation.  # noqa: E501
        :rtype: list[System]
        """
        return self._systems

    @systems.setter
    def systems(self, systems):
        """Sets the systems of this Investigation.

        The systems involved  # noqa: E501

        :param systems: The systems of this Investigation.  # noqa: E501
        :type: list[System]
        """

        self._systems = systems

    @property
    def tags(self):
        """Gets the tags of this Investigation.  # noqa: E501

        Tags  # noqa: E501

        :return: The tags of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Investigation.

        Tags  # noqa: E501

        :param tags: The tags of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this Investigation.  # noqa: E501


        :return: The type of this Investigation.  # noqa: E501
        :rtype: InvestigationType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Investigation.


        :param type: The type of this Investigation.  # noqa: E501
        :type: InvestigationType
        """

        self._type = type

    @property
    def users(self):
        """Gets the users of this Investigation.  # noqa: E501

        The users who share this investigation  # noqa: E501

        :return: The users of this Investigation.  # noqa: E501
        :rtype: list[str]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this Investigation.

        The users who share this investigation  # noqa: E501

        :param users: The users of this Investigation.  # noqa: E501
        :type: list[str]
        """

        self._users = users

    @property
    def version(self):
        """Gets the version of this Investigation.  # noqa: E501


        :return: The version of this Investigation.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Investigation.


        :param version: The version of this Investigation.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Investigation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Investigation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FileMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'info': 'str',
        'is_media_file': 'bool',
        'md5': 'str',
        'sha1': 'str',
        'sha256': 'str',
        'sha512': 'str',
        'size': 'int',
        'ssdeep': 'str',
        'type': 'str'
    }

    attribute_map = {
        'info': 'info',
        'is_media_file': 'isMediaFile',
        'md5': 'md5',
        'sha1': 'sha1',
        'sha256': 'sha256',
        'sha512': 'sha512',
        'size': 'size',
        'ssdeep': 'ssdeep',
        'type': 'type'
    }

    def __init__(self, info=None, is_media_file=None, md5=None, sha1=None, sha256=None, sha512=None, size=None, ssdeep=None, type=None):  # noqa: E501
        """FileMetadata - a model defined in Swagger"""  # noqa: E501

        self._info = None
        self._is_media_file = None
        self._md5 = None
        self._sha1 = None
        self._sha256 = None
        self._sha512 = None
        self._size = None
        self._ssdeep = None
        self._type = None
        self.discriminator = None

        if info is not None:
            self.info = info
        if is_media_file is not None:
            self.is_media_file = is_media_file
        if md5 is not None:
            self.md5 = md5
        if sha1 is not None:
            self.sha1 = sha1
        if sha256 is not None:
            self.sha256 = sha256
        if sha512 is not None:
            self.sha512 = sha512
        if size is not None:
            self.size = size
        if ssdeep is not None:
            self.ssdeep = ssdeep
        if type is not None:
            self.type = type

    @property
    def info(self):
        """Gets the info of this FileMetadata.  # noqa: E501


        :return: The info of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this FileMetadata.


        :param info: The info of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._info = info

    @property
    def is_media_file(self):
        """Gets the is_media_file of this FileMetadata.  # noqa: E501


        :return: The is_media_file of this FileMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_media_file

    @is_media_file.setter
    def is_media_file(self, is_media_file):
        """Sets the is_media_file of this FileMetadata.


        :param is_media_file: The is_media_file of this FileMetadata.  # noqa: E501
        :type: bool
        """

        self._is_media_file = is_media_file

    @property
    def md5(self):
        """Gets the md5 of this FileMetadata.  # noqa: E501


        :return: The md5 of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this FileMetadata.


        :param md5: The md5 of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._md5 = md5

    @property
    def sha1(self):
        """Gets the sha1 of this FileMetadata.  # noqa: E501


        :return: The sha1 of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this FileMetadata.


        :param sha1: The sha1 of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._sha1 = sha1

    @property
    def sha256(self):
        """Gets the sha256 of this FileMetadata.  # noqa: E501


        :return: The sha256 of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this FileMetadata.


        :param sha256: The sha256 of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    @property
    def sha512(self):
        """Gets the sha512 of this FileMetadata.  # noqa: E501


        :return: The sha512 of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._sha512

    @sha512.setter
    def sha512(self, sha512):
        """Sets the sha512 of this FileMetadata.


        :param sha512: The sha512 of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._sha512 = sha512

    @property
    def size(self):
        """Gets the size of this FileMetadata.  # noqa: E501


        :return: The size of this FileMetadata.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this FileMetadata.


        :param size: The size of this FileMetadata.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def ssdeep(self):
        """Gets the ssdeep of this FileMetadata.  # noqa: E501


        :return: The ssdeep of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._ssdeep

    @ssdeep.setter
    def ssdeep(self, ssdeep):
        """Sets the ssdeep of this FileMetadata.


        :param ssdeep: The ssdeep of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._ssdeep = ssdeep

    @property
    def type(self):
        """Gets the type of this FileMetadata.  # noqa: E501


        :return: The type of this FileMetadata.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FileMetadata.


        :param type: The type of this FileMetadata.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.dashboard import Dashboard  # noqa: F401,E501
from demisto_client.demisto_api.models.ending_type import EndingType  # noqa: F401,E501
from demisto_client.demisto_api.models.human_cron import HumanCron  # noqa: F401,E501
from demisto_client.demisto_api.models.report_fields_decoder import ReportFieldsDecoder  # noqa: F401,E501
from demisto_client.demisto_api.models.section import Section  # noqa: F401,E501


class Report(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commit_message': 'str',
        'created_by': 'str',
        'cron': 'str',
        'cron_view': 'bool',
        'dashboard': 'Dashboard',
        'decoder': 'dict(str, ReportFieldsDecoder)',
        'description': 'str',
        'disable_header': 'bool',
        'ending_date': 'datetime',
        'ending_type': 'EndingType',
        'human_cron': 'HumanCron',
        'id': 'str',
        'latest_report_name': 'str',
        'latest_report_time': 'datetime',
        'latest_report_username': 'str',
        'latest_scheduled_report_time': 'datetime',
        'locked': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'next_scheduled_time': 'datetime',
        'orientation': 'str',
        'paper_size': 'str',
        'prev_name': 'str',
        'prev_type': 'str',
        'recipients': 'list[str]',
        'recurrent': 'bool',
        'report_type': 'str',
        'run_once': 'bool',
        'running_user': 'str',
        'scheduled': 'bool',
        'sections': 'list[Section]',
        'sensitive': 'bool',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'start_date': 'datetime',
        'system': 'bool',
        'tags': 'list[str]',
        'times': 'int',
        'timezone_offset': 'int',
        'type': 'str',
        'user_api_key': 'str',
        'user_api_key_id': 'str',
        'vc_should_ignore': 'bool',
        'version': 'int'
    }

    attribute_map = {
        'commit_message': 'commitMessage',
        'created_by': 'createdBy',
        'cron': 'cron',
        'cron_view': 'cronView',
        'dashboard': 'dashboard',
        'decoder': 'decoder',
        'description': 'description',
        'disable_header': 'disableHeader',
        'ending_date': 'endingDate',
        'ending_type': 'endingType',
        'human_cron': 'humanCron',
        'id': 'id',
        'latest_report_name': 'latestReportName',
        'latest_report_time': 'latestReportTime',
        'latest_report_username': 'latestReportUsername',
        'latest_scheduled_report_time': 'latestScheduledReportTime',
        'locked': 'locked',
        'modified': 'modified',
        'name': 'name',
        'next_scheduled_time': 'nextScheduledTime',
        'orientation': 'orientation',
        'paper_size': 'paperSize',
        'prev_name': 'prevName',
        'prev_type': 'prevType',
        'recipients': 'recipients',
        'recurrent': 'recurrent',
        'report_type': 'reportType',
        'run_once': 'runOnce',
        'running_user': 'runningUser',
        'scheduled': 'scheduled',
        'sections': 'sections',
        'sensitive': 'sensitive',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'start_date': 'startDate',
        'system': 'system',
        'tags': 'tags',
        'times': 'times',
        'timezone_offset': 'timezoneOffset',
        'type': 'type',
        'user_api_key': 'userAPIKey',
        'user_api_key_id': 'userAPIKeyID',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version'
    }

    def __init__(self, commit_message=None, created_by=None, cron=None, cron_view=None, dashboard=None, decoder=None, description=None, disable_header=None, ending_date=None, ending_type=None, human_cron=None, id=None, latest_report_name=None, latest_report_time=None, latest_report_username=None, latest_scheduled_report_time=None, locked=None, modified=None, name=None, next_scheduled_time=None, orientation=None, paper_size=None, prev_name=None, prev_type=None, recipients=None, recurrent=None, report_type=None, run_once=None, running_user=None, scheduled=None, sections=None, sensitive=None, should_commit=None, sort_values=None, start_date=None, system=None, tags=None, times=None, timezone_offset=None, type=None, user_api_key=None, user_api_key_id=None, vc_should_ignore=None, version=None):  # noqa: E501
        """Report - a model defined in Swagger"""  # noqa: E501

        self._commit_message = None
        self._created_by = None
        self._cron = None
        self._cron_view = None
        self._dashboard = None
        self._decoder = None
        self._description = None
        self._disable_header = None
        self._ending_date = None
        self._ending_type = None
        self._human_cron = None
        self._id = None
        self._latest_report_name = None
        self._latest_report_time = None
        self._latest_report_username = None
        self._latest_scheduled_report_time = None
        self._locked = None
        self._modified = None
        self._name = None
        self._next_scheduled_time = None
        self._orientation = None
        self._paper_size = None
        self._prev_name = None
        self._prev_type = None
        self._recipients = None
        self._recurrent = None
        self._report_type = None
        self._run_once = None
        self._running_user = None
        self._scheduled = None
        self._sections = None
        self._sensitive = None
        self._should_commit = None
        self._sort_values = None
        self._start_date = None
        self._system = None
        self._tags = None
        self._times = None
        self._timezone_offset = None
        self._type = None
        self._user_api_key = None
        self._user_api_key_id = None
        self._vc_should_ignore = None
        self._version = None
        self.discriminator = None

        if commit_message is not None:
            self.commit_message = commit_message
        if created_by is not None:
            self.created_by = created_by
        if cron is not None:
            self.cron = cron
        if cron_view is not None:
            self.cron_view = cron_view
        if dashboard is not None:
            self.dashboard = dashboard
        if decoder is not None:
            self.decoder = decoder
        if description is not None:
            self.description = description
        if disable_header is not None:
            self.disable_header = disable_header
        if ending_date is not None:
            self.ending_date = ending_date
        if ending_type is not None:
            self.ending_type = ending_type
        if human_cron is not None:
            self.human_cron = human_cron
        if id is not None:
            self.id = id
        if latest_report_name is not None:
            self.latest_report_name = latest_report_name
        if latest_report_time is not None:
            self.latest_report_time = latest_report_time
        if latest_report_username is not None:
            self.latest_report_username = latest_report_username
        if latest_scheduled_report_time is not None:
            self.latest_scheduled_report_time = latest_scheduled_report_time
        if locked is not None:
            self.locked = locked
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if next_scheduled_time is not None:
            self.next_scheduled_time = next_scheduled_time
        if orientation is not None:
            self.orientation = orientation
        if paper_size is not None:
            self.paper_size = paper_size
        if prev_name is not None:
            self.prev_name = prev_name
        if prev_type is not None:
            self.prev_type = prev_type
        if recipients is not None:
            self.recipients = recipients
        if recurrent is not None:
            self.recurrent = recurrent
        if report_type is not None:
            self.report_type = report_type
        if run_once is not None:
            self.run_once = run_once
        if running_user is not None:
            self.running_user = running_user
        if scheduled is not None:
            self.scheduled = scheduled
        if sections is not None:
            self.sections = sections
        if sensitive is not None:
            self.sensitive = sensitive
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if start_date is not None:
            self.start_date = start_date
        if system is not None:
            self.system = system
        if tags is not None:
            self.tags = tags
        if times is not None:
            self.times = times
        if timezone_offset is not None:
            self.timezone_offset = timezone_offset
        if type is not None:
            self.type = type
        if user_api_key is not None:
            self.user_api_key = user_api_key
        if user_api_key_id is not None:
            self.user_api_key_id = user_api_key_id
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version

    @property
    def commit_message(self):
        """Gets the commit_message of this Report.  # noqa: E501


        :return: The commit_message of this Report.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this Report.


        :param commit_message: The commit_message of this Report.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def created_by(self):
        """Gets the created_by of this Report.  # noqa: E501


        :return: The created_by of this Report.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Report.


        :param created_by: The created_by of this Report.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def cron(self):
        """Gets the cron of this Report.  # noqa: E501


        :return: The cron of this Report.  # noqa: E501
        :rtype: str
        """
        return self._cron

    @cron.setter
    def cron(self, cron):
        """Sets the cron of this Report.


        :param cron: The cron of this Report.  # noqa: E501
        :type: str
        """

        self._cron = cron

    @property
    def cron_view(self):
        """Gets the cron_view of this Report.  # noqa: E501


        :return: The cron_view of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._cron_view

    @cron_view.setter
    def cron_view(self, cron_view):
        """Sets the cron_view of this Report.


        :param cron_view: The cron_view of this Report.  # noqa: E501
        :type: bool
        """

        self._cron_view = cron_view

    @property
    def dashboard(self):
        """Gets the dashboard of this Report.  # noqa: E501


        :return: The dashboard of this Report.  # noqa: E501
        :rtype: Dashboard
        """
        return self._dashboard

    @dashboard.setter
    def dashboard(self, dashboard):
        """Sets the dashboard of this Report.


        :param dashboard: The dashboard of this Report.  # noqa: E501
        :type: Dashboard
        """

        self._dashboard = dashboard

    @property
    def decoder(self):
        """Gets the decoder of this Report.  # noqa: E501


        :return: The decoder of this Report.  # noqa: E501
        :rtype: dict(str, ReportFieldsDecoder)
        """
        return self._decoder

    @decoder.setter
    def decoder(self, decoder):
        """Sets the decoder of this Report.


        :param decoder: The decoder of this Report.  # noqa: E501
        :type: dict(str, ReportFieldsDecoder)
        """

        self._decoder = decoder

    @property
    def description(self):
        """Gets the description of this Report.  # noqa: E501


        :return: The description of this Report.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Report.


        :param description: The description of this Report.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def disable_header(self):
        """Gets the disable_header of this Report.  # noqa: E501


        :return: The disable_header of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._disable_header

    @disable_header.setter
    def disable_header(self, disable_header):
        """Sets the disable_header of this Report.


        :param disable_header: The disable_header of this Report.  # noqa: E501
        :type: bool
        """

        self._disable_header = disable_header

    @property
    def ending_date(self):
        """Gets the ending_date of this Report.  # noqa: E501


        :return: The ending_date of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._ending_date

    @ending_date.setter
    def ending_date(self, ending_date):
        """Sets the ending_date of this Report.


        :param ending_date: The ending_date of this Report.  # noqa: E501
        :type: datetime
        """

        self._ending_date = ending_date

    @property
    def ending_type(self):
        """Gets the ending_type of this Report.  # noqa: E501


        :return: The ending_type of this Report.  # noqa: E501
        :rtype: EndingType
        """
        return self._ending_type

    @ending_type.setter
    def ending_type(self, ending_type):
        """Sets the ending_type of this Report.


        :param ending_type: The ending_type of this Report.  # noqa: E501
        :type: EndingType
        """

        self._ending_type = ending_type

    @property
    def human_cron(self):
        """Gets the human_cron of this Report.  # noqa: E501


        :return: The human_cron of this Report.  # noqa: E501
        :rtype: HumanCron
        """
        return self._human_cron

    @human_cron.setter
    def human_cron(self, human_cron):
        """Sets the human_cron of this Report.


        :param human_cron: The human_cron of this Report.  # noqa: E501
        :type: HumanCron
        """

        self._human_cron = human_cron

    @property
    def id(self):
        """Gets the id of this Report.  # noqa: E501


        :return: The id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Report.


        :param id: The id of this Report.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def latest_report_name(self):
        """Gets the latest_report_name of this Report.  # noqa: E501


        :return: The latest_report_name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._latest_report_name

    @latest_report_name.setter
    def latest_report_name(self, latest_report_name):
        """Sets the latest_report_name of this Report.


        :param latest_report_name: The latest_report_name of this Report.  # noqa: E501
        :type: str
        """

        self._latest_report_name = latest_report_name

    @property
    def latest_report_time(self):
        """Gets the latest_report_time of this Report.  # noqa: E501


        :return: The latest_report_time of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._latest_report_time

    @latest_report_time.setter
    def latest_report_time(self, latest_report_time):
        """Sets the latest_report_time of this Report.


        :param latest_report_time: The latest_report_time of this Report.  # noqa: E501
        :type: datetime
        """

        self._latest_report_time = latest_report_time

    @property
    def latest_report_username(self):
        """Gets the latest_report_username of this Report.  # noqa: E501


        :return: The latest_report_username of this Report.  # noqa: E501
        :rtype: str
        """
        return self._latest_report_username

    @latest_report_username.setter
    def latest_report_username(self, latest_report_username):
        """Sets the latest_report_username of this Report.


        :param latest_report_username: The latest_report_username of this Report.  # noqa: E501
        :type: str
        """

        self._latest_report_username = latest_report_username

    @property
    def latest_scheduled_report_time(self):
        """Gets the latest_scheduled_report_time of this Report.  # noqa: E501


        :return: The latest_scheduled_report_time of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._latest_scheduled_report_time

    @latest_scheduled_report_time.setter
    def latest_scheduled_report_time(self, latest_scheduled_report_time):
        """Sets the latest_scheduled_report_time of this Report.


        :param latest_scheduled_report_time: The latest_scheduled_report_time of this Report.  # noqa: E501
        :type: datetime
        """

        self._latest_scheduled_report_time = latest_scheduled_report_time

    @property
    def locked(self):
        """Gets the locked of this Report.  # noqa: E501


        :return: The locked of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this Report.


        :param locked: The locked of this Report.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def modified(self):
        """Gets the modified of this Report.  # noqa: E501


        :return: The modified of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Report.


        :param modified: The modified of this Report.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Report.  # noqa: E501


        :return: The name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Report.


        :param name: The name of this Report.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def next_scheduled_time(self):
        """Gets the next_scheduled_time of this Report.  # noqa: E501


        :return: The next_scheduled_time of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._next_scheduled_time

    @next_scheduled_time.setter
    def next_scheduled_time(self, next_scheduled_time):
        """Sets the next_scheduled_time of this Report.


        :param next_scheduled_time: The next_scheduled_time of this Report.  # noqa: E501
        :type: datetime
        """

        self._next_scheduled_time = next_scheduled_time

    @property
    def orientation(self):
        """Gets the orientation of this Report.  # noqa: E501


        :return: The orientation of this Report.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this Report.


        :param orientation: The orientation of this Report.  # noqa: E501
        :type: str
        """

        self._orientation = orientation

    @property
    def paper_size(self):
        """Gets the paper_size of this Report.  # noqa: E501


        :return: The paper_size of this Report.  # noqa: E501
        :rtype: str
        """
        return self._paper_size

    @paper_size.setter
    def paper_size(self, paper_size):
        """Sets the paper_size of this Report.


        :param paper_size: The paper_size of this Report.  # noqa: E501
        :type: str
        """

        self._paper_size = paper_size

    @property
    def prev_name(self):
        """Gets the prev_name of this Report.  # noqa: E501


        :return: The prev_name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this Report.


        :param prev_name: The prev_name of this Report.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def prev_type(self):
        """Gets the prev_type of this Report.  # noqa: E501


        :return: The prev_type of this Report.  # noqa: E501
        :rtype: str
        """
        return self._prev_type

    @prev_type.setter
    def prev_type(self, prev_type):
        """Sets the prev_type of this Report.


        :param prev_type: The prev_type of this Report.  # noqa: E501
        :type: str
        """

        self._prev_type = prev_type

    @property
    def recipients(self):
        """Gets the recipients of this Report.  # noqa: E501


        :return: The recipients of this Report.  # noqa: E501
        :rtype: list[str]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this Report.


        :param recipients: The recipients of this Report.  # noqa: E501
        :type: list[str]
        """

        self._recipients = recipients

    @property
    def recurrent(self):
        """Gets the recurrent of this Report.  # noqa: E501


        :return: The recurrent of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._recurrent

    @recurrent.setter
    def recurrent(self, recurrent):
        """Sets the recurrent of this Report.


        :param recurrent: The recurrent of this Report.  # noqa: E501
        :type: bool
        """

        self._recurrent = recurrent

    @property
    def report_type(self):
        """Gets the report_type of this Report.  # noqa: E501


        :return: The report_type of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this Report.


        :param report_type: The report_type of this Report.  # noqa: E501
        :type: str
        """

        self._report_type = report_type

    @property
    def run_once(self):
        """Gets the run_once of this Report.  # noqa: E501


        :return: The run_once of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._run_once

    @run_once.setter
    def run_once(self, run_once):
        """Sets the run_once of this Report.


        :param run_once: The run_once of this Report.  # noqa: E501
        :type: bool
        """

        self._run_once = run_once

    @property
    def running_user(self):
        """Gets the running_user of this Report.  # noqa: E501


        :return: The running_user of this Report.  # noqa: E501
        :rtype: str
        """
        return self._running_user

    @running_user.setter
    def running_user(self, running_user):
        """Sets the running_user of this Report.


        :param running_user: The running_user of this Report.  # noqa: E501
        :type: str
        """

        self._running_user = running_user

    @property
    def scheduled(self):
        """Gets the scheduled of this Report.  # noqa: E501

        is it scheduled  # noqa: E501

        :return: The scheduled of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._scheduled

    @scheduled.setter
    def scheduled(self, scheduled):
        """Sets the scheduled of this Report.

        is it scheduled  # noqa: E501

        :param scheduled: The scheduled of this Report.  # noqa: E501
        :type: bool
        """

        self._scheduled = scheduled

    @property
    def sections(self):
        """Gets the sections of this Report.  # noqa: E501


        :return: The sections of this Report.  # noqa: E501
        :rtype: list[Section]
        """
        return self._sections

    @sections.setter
    def sections(self, sections):
        """Sets the sections of this Report.


        :param sections: The sections of this Report.  # noqa: E501
        :type: list[Section]
        """

        self._sections = sections

    @property
    def sensitive(self):
        """Gets the sensitive of this Report.  # noqa: E501


        :return: The sensitive of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._sensitive

    @sensitive.setter
    def sensitive(self, sensitive):
        """Sets the sensitive of this Report.


        :param sensitive: The sensitive of this Report.  # noqa: E501
        :type: bool
        """

        self._sensitive = sensitive

    @property
    def should_commit(self):
        """Gets the should_commit of this Report.  # noqa: E501


        :return: The should_commit of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this Report.


        :param should_commit: The should_commit of this Report.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this Report.  # noqa: E501


        :return: The sort_values of this Report.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Report.


        :param sort_values: The sort_values of this Report.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def start_date(self):
        """Gets the start_date of this Report.  # noqa: E501


        :return: The start_date of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Report.


        :param start_date: The start_date of this Report.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def system(self):
        """Gets the system of this Report.  # noqa: E501


        :return: The system of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Report.


        :param system: The system of this Report.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def tags(self):
        """Gets the tags of this Report.  # noqa: E501


        :return: The tags of this Report.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Report.


        :param tags: The tags of this Report.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def times(self):
        """Gets the times of this Report.  # noqa: E501


        :return: The times of this Report.  # noqa: E501
        :rtype: int
        """
        return self._times

    @times.setter
    def times(self, times):
        """Sets the times of this Report.


        :param times: The times of this Report.  # noqa: E501
        :type: int
        """

        self._times = times

    @property
    def timezone_offset(self):
        """Gets the timezone_offset of this Report.  # noqa: E501


        :return: The timezone_offset of this Report.  # noqa: E501
        :rtype: int
        """
        return self._timezone_offset

    @timezone_offset.setter
    def timezone_offset(self, timezone_offset):
        """Sets the timezone_offset of this Report.


        :param timezone_offset: The timezone_offset of this Report.  # noqa: E501
        :type: int
        """

        self._timezone_offset = timezone_offset

    @property
    def type(self):
        """Gets the type of this Report.  # noqa: E501


        :return: The type of this Report.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Report.


        :param type: The type of this Report.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def user_api_key(self):
        """Gets the user_api_key of this Report.  # noqa: E501


        :return: The user_api_key of this Report.  # noqa: E501
        :rtype: str
        """
        return self._user_api_key

    @user_api_key.setter
    def user_api_key(self, user_api_key):
        """Sets the user_api_key of this Report.


        :param user_api_key: The user_api_key of this Report.  # noqa: E501
        :type: str
        """

        self._user_api_key = user_api_key

    @property
    def user_api_key_id(self):
        """Gets the user_api_key_id of this Report.  # noqa: E501


        :return: The user_api_key_id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._user_api_key_id

    @user_api_key_id.setter
    def user_api_key_id(self, user_api_key_id):
        """Sets the user_api_key_id of this Report.


        :param user_api_key_id: The user_api_key_id of this Report.  # noqa: E501
        :type: str
        """

        self._user_api_key_id = user_api_key_id

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this Report.  # noqa: E501


        :return: The vc_should_ignore of this Report.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this Report.


        :param vc_should_ignore: The vc_should_ignore of this Report.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this Report.  # noqa: E501


        :return: The version of this Report.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Report.


        :param version: The version of this Report.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Report, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Report):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Evidence(dict):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shard_id': 'int',
        'description': 'str',
        'entry_id': 'str',
        'fetched': 'datetime',
        'has_role': 'bool',
        'id': 'str',
        'incident_id': 'str',
        'marked_by': 'str',
        'marked_date': 'datetime',
        'modified': 'datetime',
        'occurred': 'datetime',
        'previous_roles': 'list[str]',
        'roles': 'list[str]',
        'sort_values': 'list[str]',
        'tags': 'list[str]',
        'tags_raw': 'list[str]',
        'task_id': 'str',
        'version': 'int'
    }

    attribute_map = {
        'shard_id': 'ShardID',
        'description': 'description',
        'entry_id': 'entryId',
        'fetched': 'fetched',
        'has_role': 'hasRole',
        'id': 'id',
        'incident_id': 'incidentId',
        'marked_by': 'markedBy',
        'marked_date': 'markedDate',
        'modified': 'modified',
        'occurred': 'occurred',
        'previous_roles': 'previousRoles',
        'roles': 'roles',
        'sort_values': 'sortValues',
        'tags': 'tags',
        'tags_raw': 'tagsRaw',
        'task_id': 'taskId',
        'version': 'version'
    }

    def __init__(self, shard_id=None, description=None, entry_id=None, fetched=None, has_role=None, id=None, incident_id=None, marked_by=None, marked_date=None, modified=None, occurred=None, previous_roles=None, roles=None, sort_values=None, tags=None, tags_raw=None, task_id=None, version=None):  # noqa: E501
        """Evidence - a model defined in Swagger"""  # noqa: E501

        self._shard_id = None
        self._description = None
        self._entry_id = None
        self._fetched = None
        self._has_role = None
        self._id = None
        self._incident_id = None
        self._marked_by = None
        self._marked_date = None
        self._modified = None
        self._occurred = None
        self._previous_roles = None
        self._roles = None
        self._sort_values = None
        self._tags = None
        self._tags_raw = None
        self._task_id = None
        self._version = None
        self.discriminator = None

        if shard_id is not None:
            self.shard_id = shard_id
        if description is not None:
            self.description = description
        if entry_id is not None:
            self.entry_id = entry_id
        if fetched is not None:
            self.fetched = fetched
        if has_role is not None:
            self.has_role = has_role
        if id is not None:
            self.id = id
        if incident_id is not None:
            self.incident_id = incident_id
        if marked_by is not None:
            self.marked_by = marked_by
        if marked_date is not None:
            self.marked_date = marked_date
        if modified is not None:
            self.modified = modified
        if occurred is not None:
            self.occurred = occurred
        if previous_roles is not None:
            self.previous_roles = previous_roles
        if roles is not None:
            self.roles = roles
        if sort_values is not None:
            self.sort_values = sort_values
        if tags is not None:
            self.tags = tags
        if tags_raw is not None:
            self.tags_raw = tags_raw
        if task_id is not None:
            self.task_id = task_id
        if version is not None:
            self.version = version

    @property
    def shard_id(self):
        """Gets the shard_id of this Evidence.  # noqa: E501


        :return: The shard_id of this Evidence.  # noqa: E501
        :rtype: int
        """
        return self._shard_id

    @shard_id.setter
    def shard_id(self, shard_id):
        """Sets the shard_id of this Evidence.


        :param shard_id: The shard_id of this Evidence.  # noqa: E501
        :type: int
        """

        self._shard_id = shard_id

    @property
    def description(self):
        """Gets the description of this Evidence.  # noqa: E501

        The description for the resolve  # noqa: E501

        :return: The description of this Evidence.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Evidence.

        The description for the resolve  # noqa: E501

        :param description: The description of this Evidence.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def entry_id(self):
        """Gets the entry_id of this Evidence.  # noqa: E501

        The entry ID  # noqa: E501

        :return: The entry_id of this Evidence.  # noqa: E501
        :rtype: str
        """
        return self._entry_id

    @entry_id.setter
    def entry_id(self, entry_id):
        """Sets the entry_id of this Evidence.

        The entry ID  # noqa: E501

        :param entry_id: The entry_id of this Evidence.  # noqa: E501
        :type: str
        """

        self._entry_id = entry_id

    @property
    def fetched(self):
        """Gets the fetched of this Evidence.  # noqa: E501

        when the evidence entry was fetched  # noqa: E501

        :return: The fetched of this Evidence.  # noqa: E501
        :rtype: datetime
        """
        return self._fetched

    @fetched.setter
    def fetched(self, fetched):
        """Sets the fetched of this Evidence.

        when the evidence entry was fetched  # noqa: E501

        :param fetched: The fetched of this Evidence.  # noqa: E501
        :type: datetime
        """

        self._fetched = fetched

    @property
    def has_role(self):
        """Gets the has_role of this Evidence.  # noqa: E501

        Internal field to make queries on role faster  # noqa: E501

        :return: The has_role of this Evidence.  # noqa: E501
        :rtype: bool
        """
        return self._has_role

    @has_role.setter
    def has_role(self, has_role):
        """Sets the has_role of this Evidence.

        Internal field to make queries on role faster  # noqa: E501

        :param has_role: The has_role of this Evidence.  # noqa: E501
        :type: bool
        """

        self._has_role = has_role

    @property
    def id(self):
        """Gets the id of this Evidence.  # noqa: E501


        :return: The id of this Evidence.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Evidence.


        :param id: The id of this Evidence.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def incident_id(self):
        """Gets the incident_id of this Evidence.  # noqa: E501

        The incident ID  # noqa: E501

        :return: The incident_id of this Evidence.  # noqa: E501
        :rtype: str
        """
        return self._incident_id

    @incident_id.setter
    def incident_id(self, incident_id):
        """Sets the incident_id of this Evidence.

        The incident ID  # noqa: E501

        :param incident_id: The incident_id of this Evidence.  # noqa: E501
        :type: str
        """

        self._incident_id = incident_id

    @property
    def marked_by(self):
        """Gets the marked_by of this Evidence.  # noqa: E501

        the user that marked this evidence  # noqa: E501

        :return: The marked_by of this Evidence.  # noqa: E501
        :rtype: str
        """
        return self._marked_by

    @marked_by.setter
    def marked_by(self, marked_by):
        """Sets the marked_by of this Evidence.

        the user that marked this evidence  # noqa: E501

        :param marked_by: The marked_by of this Evidence.  # noqa: E501
        :type: str
        """

        self._marked_by = marked_by

    @property
    def marked_date(self):
        """Gets the marked_date of this Evidence.  # noqa: E501

        when this evidence was marked  # noqa: E501

        :return: The marked_date of this Evidence.  # noqa: E501
        :rtype: datetime
        """
        return self._marked_date

    @marked_date.setter
    def marked_date(self, marked_date):
        """Sets the marked_date of this Evidence.

        when this evidence was marked  # noqa: E501

        :param marked_date: The marked_date of this Evidence.  # noqa: E501
        :type: datetime
        """

        self._marked_date = marked_date

    @property
    def modified(self):
        """Gets the modified of this Evidence.  # noqa: E501


        :return: The modified of this Evidence.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Evidence.


        :param modified: The modified of this Evidence.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def occurred(self):
        """Gets the occurred of this Evidence.  # noqa: E501

        When this evidence has occurred  # noqa: E501

        :return: The occurred of this Evidence.  # noqa: E501
        :rtype: datetime
        """
        return self._occurred

    @occurred.setter
    def occurred(self, occurred):
        """Sets the occurred of this Evidence.

        When this evidence has occurred  # noqa: E501

        :param occurred: The occurred of this Evidence.  # noqa: E501
        :type: datetime
        """

        self._occurred = occurred

    @property
    def previous_roles(self):
        """Gets the previous_roles of this Evidence.  # noqa: E501

        PreviousRoleName - do not change this field manually  # noqa: E501

        :return: The previous_roles of this Evidence.  # noqa: E501
        :rtype: list[str]
        """
        return self._previous_roles

    @previous_roles.setter
    def previous_roles(self, previous_roles):
        """Sets the previous_roles of this Evidence.

        PreviousRoleName - do not change this field manually  # noqa: E501

        :param previous_roles: The previous_roles of this Evidence.  # noqa: E501
        :type: list[str]
        """

        self._previous_roles = previous_roles

    @property
    def roles(self):
        """Gets the roles of this Evidence.  # noqa: E501

        The role assigned to this investigation  # noqa: E501

        :return: The roles of this Evidence.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Evidence.

        The role assigned to this investigation  # noqa: E501

        :param roles: The roles of this Evidence.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def sort_values(self):
        """Gets the sort_values of this Evidence.  # noqa: E501


        :return: The sort_values of this Evidence.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Evidence.


        :param sort_values: The sort_values of this Evidence.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def tags(self):
        """Gets the tags of this Evidence.  # noqa: E501

        Tags  # noqa: E501

        :return: The tags of this Evidence.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Evidence.

        Tags  # noqa: E501

        :param tags: The tags of this Evidence.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def tags_raw(self):
        """Gets the tags_raw of this Evidence.  # noqa: E501

        TagsRaw  # noqa: E501

        :return: The tags_raw of this Evidence.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags_raw

    @tags_raw.setter
    def tags_raw(self, tags_raw):
        """Sets the tags_raw of this Evidence.

        TagsRaw  # noqa: E501

        :param tags_raw: The tags_raw of this Evidence.  # noqa: E501
        :type: list[str]
        """

        self._tags_raw = tags_raw

    @property
    def task_id(self):
        """Gets the task_id of this Evidence.  # noqa: E501

        when the evidence entry was fetched  # noqa: E501

        :return: The task_id of this Evidence.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this Evidence.

        when the evidence entry was fetched  # noqa: E501

        :param task_id: The task_id of this Evidence.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def version(self):
        """Gets the version of this Evidence.  # noqa: E501


        :return: The version of this Evidence.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Evidence.


        :param version: The version of this Evidence.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Evidence, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Evidence):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.config_field import ConfigField  # noqa: F401,E501
from demisto_client.demisto_api.models.integration_script import IntegrationScript  # noqa: F401,E501


class ModuleConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beta': 'bool',
        'brand': 'str',
        'can_get_samples': 'bool',
        'category': 'str',
        'cmdline': 'str',
        'commit_message': 'str',
        'configuration': 'list[ConfigField]',
        'deprecated': 'bool',
        'description': 'str',
        'detailed_description': 'str',
        'display': 'str',
        'executable': 'str',
        'hidden': 'bool',
        'hide_engines': 'bool',
        'icon': 'str',
        'id': 'str',
        'image': 'str',
        'integration_script': 'IntegrationScript',
        'is_password_protected': 'bool',
        'locked': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'path': 'str',
        'prev_name': 'str',
        'propagation_labels': 'list[str]',
        'readonly': 'bool',
        'script_not_visible': 'bool',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'source_module_id': 'str',
        'system': 'bool',
        'vc_should_ignore': 'bool',
        'version': 'int'
    }

    attribute_map = {
        'beta': 'beta',
        'brand': 'brand',
        'can_get_samples': 'canGetSamples',
        'category': 'category',
        'cmdline': 'cmdline',
        'commit_message': 'commitMessage',
        'configuration': 'configuration',
        'deprecated': 'deprecated',
        'description': 'description',
        'detailed_description': 'detailedDescription',
        'display': 'display',
        'executable': 'executable',
        'hidden': 'hidden',
        'hide_engines': 'hideEngines',
        'icon': 'icon',
        'id': 'id',
        'image': 'image',
        'integration_script': 'integrationScript',
        'is_password_protected': 'isPasswordProtected',
        'locked': 'locked',
        'modified': 'modified',
        'name': 'name',
        'path': 'path',
        'prev_name': 'prevName',
        'propagation_labels': 'propagationLabels',
        'readonly': 'readonly',
        'script_not_visible': 'scriptNotVisible',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'source_module_id': 'sourceModuleID',
        'system': 'system',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version'
    }

    def __init__(self, beta=None, brand=None, can_get_samples=None, category=None, cmdline=None, commit_message=None, configuration=None, deprecated=None, description=None, detailed_description=None, display=None, executable=None, hidden=None, hide_engines=None, icon=None, id=None, image=None, integration_script=None, is_password_protected=None, locked=None, modified=None, name=None, path=None, prev_name=None, propagation_labels=None, readonly=None, script_not_visible=None, should_commit=None, sort_values=None, source_module_id=None, system=None, vc_should_ignore=None, version=None):  # noqa: E501
        """ModuleConfiguration - a model defined in Swagger"""  # noqa: E501

        self._beta = None
        self._brand = None
        self._can_get_samples = None
        self._category = None
        self._cmdline = None
        self._commit_message = None
        self._configuration = None
        self._deprecated = None
        self._description = None
        self._detailed_description = None
        self._display = None
        self._executable = None
        self._hidden = None
        self._hide_engines = None
        self._icon = None
        self._id = None
        self._image = None
        self._integration_script = None
        self._is_password_protected = None
        self._locked = None
        self._modified = None
        self._name = None
        self._path = None
        self._prev_name = None
        self._propagation_labels = None
        self._readonly = None
        self._script_not_visible = None
        self._should_commit = None
        self._sort_values = None
        self._source_module_id = None
        self._system = None
        self._vc_should_ignore = None
        self._version = None
        self.discriminator = None

        if beta is not None:
            self.beta = beta
        if brand is not None:
            self.brand = brand
        if can_get_samples is not None:
            self.can_get_samples = can_get_samples
        if category is not None:
            self.category = category
        if cmdline is not None:
            self.cmdline = cmdline
        if commit_message is not None:
            self.commit_message = commit_message
        if configuration is not None:
            self.configuration = configuration
        if deprecated is not None:
            self.deprecated = deprecated
        if description is not None:
            self.description = description
        if detailed_description is not None:
            self.detailed_description = detailed_description
        if display is not None:
            self.display = display
        if executable is not None:
            self.executable = executable
        if hidden is not None:
            self.hidden = hidden
        if hide_engines is not None:
            self.hide_engines = hide_engines
        if icon is not None:
            self.icon = icon
        if id is not None:
            self.id = id
        if image is not None:
            self.image = image
        if integration_script is not None:
            self.integration_script = integration_script
        if is_password_protected is not None:
            self.is_password_protected = is_password_protected
        if locked is not None:
            self.locked = locked
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if path is not None:
            self.path = path
        if prev_name is not None:
            self.prev_name = prev_name
        if propagation_labels is not None:
            self.propagation_labels = propagation_labels
        if readonly is not None:
            self.readonly = readonly
        if script_not_visible is not None:
            self.script_not_visible = script_not_visible
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if source_module_id is not None:
            self.source_module_id = source_module_id
        if system is not None:
            self.system = system
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version

    @property
    def beta(self):
        """Gets the beta of this ModuleConfiguration.  # noqa: E501


        :return: The beta of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._beta

    @beta.setter
    def beta(self, beta):
        """Sets the beta of this ModuleConfiguration.


        :param beta: The beta of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._beta = beta

    @property
    def brand(self):
        """Gets the brand of this ModuleConfiguration.  # noqa: E501


        :return: The brand of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this ModuleConfiguration.


        :param brand: The brand of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def can_get_samples(self):
        """Gets the can_get_samples of this ModuleConfiguration.  # noqa: E501


        :return: The can_get_samples of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._can_get_samples

    @can_get_samples.setter
    def can_get_samples(self, can_get_samples):
        """Sets the can_get_samples of this ModuleConfiguration.


        :param can_get_samples: The can_get_samples of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._can_get_samples = can_get_samples

    @property
    def category(self):
        """Gets the category of this ModuleConfiguration.  # noqa: E501


        :return: The category of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ModuleConfiguration.


        :param category: The category of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def cmdline(self):
        """Gets the cmdline of this ModuleConfiguration.  # noqa: E501


        :return: The cmdline of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._cmdline

    @cmdline.setter
    def cmdline(self, cmdline):
        """Sets the cmdline of this ModuleConfiguration.


        :param cmdline: The cmdline of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._cmdline = cmdline

    @property
    def commit_message(self):
        """Gets the commit_message of this ModuleConfiguration.  # noqa: E501


        :return: The commit_message of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this ModuleConfiguration.


        :param commit_message: The commit_message of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def configuration(self):
        """Gets the configuration of this ModuleConfiguration.  # noqa: E501


        :return: The configuration of this ModuleConfiguration.  # noqa: E501
        :rtype: list[ConfigField]
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this ModuleConfiguration.


        :param configuration: The configuration of this ModuleConfiguration.  # noqa: E501
        :type: list[ConfigField]
        """

        self._configuration = configuration

    @property
    def deprecated(self):
        """Gets the deprecated of this ModuleConfiguration.  # noqa: E501


        :return: The deprecated of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this ModuleConfiguration.


        :param deprecated: The deprecated of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def description(self):
        """Gets the description of this ModuleConfiguration.  # noqa: E501


        :return: The description of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ModuleConfiguration.


        :param description: The description of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def detailed_description(self):
        """Gets the detailed_description of this ModuleConfiguration.  # noqa: E501


        :return: The detailed_description of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._detailed_description

    @detailed_description.setter
    def detailed_description(self, detailed_description):
        """Sets the detailed_description of this ModuleConfiguration.


        :param detailed_description: The detailed_description of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._detailed_description = detailed_description

    @property
    def display(self):
        """Gets the display of this ModuleConfiguration.  # noqa: E501


        :return: The display of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this ModuleConfiguration.


        :param display: The display of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._display = display

    @property
    def executable(self):
        """Gets the executable of this ModuleConfiguration.  # noqa: E501


        :return: The executable of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._executable

    @executable.setter
    def executable(self, executable):
        """Sets the executable of this ModuleConfiguration.


        :param executable: The executable of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._executable = executable

    @property
    def hidden(self):
        """Gets the hidden of this ModuleConfiguration.  # noqa: E501


        :return: The hidden of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this ModuleConfiguration.


        :param hidden: The hidden of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def hide_engines(self):
        """Gets the hide_engines of this ModuleConfiguration.  # noqa: E501


        :return: The hide_engines of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._hide_engines

    @hide_engines.setter
    def hide_engines(self, hide_engines):
        """Sets the hide_engines of this ModuleConfiguration.


        :param hide_engines: The hide_engines of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._hide_engines = hide_engines

    @property
    def icon(self):
        """Gets the icon of this ModuleConfiguration.  # noqa: E501


        :return: The icon of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this ModuleConfiguration.


        :param icon: The icon of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def id(self):
        """Gets the id of this ModuleConfiguration.  # noqa: E501


        :return: The id of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModuleConfiguration.


        :param id: The id of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def image(self):
        """Gets the image of this ModuleConfiguration.  # noqa: E501


        :return: The image of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this ModuleConfiguration.


        :param image: The image of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def integration_script(self):
        """Gets the integration_script of this ModuleConfiguration.  # noqa: E501


        :return: The integration_script of this ModuleConfiguration.  # noqa: E501
        :rtype: IntegrationScript
        """
        return self._integration_script

    @integration_script.setter
    def integration_script(self, integration_script):
        """Sets the integration_script of this ModuleConfiguration.


        :param integration_script: The integration_script of this ModuleConfiguration.  # noqa: E501
        :type: IntegrationScript
        """

        self._integration_script = integration_script

    @property
    def is_password_protected(self):
        """Gets the is_password_protected of this ModuleConfiguration.  # noqa: E501


        :return: The is_password_protected of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._is_password_protected

    @is_password_protected.setter
    def is_password_protected(self, is_password_protected):
        """Sets the is_password_protected of this ModuleConfiguration.


        :param is_password_protected: The is_password_protected of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._is_password_protected = is_password_protected

    @property
    def locked(self):
        """Gets the locked of this ModuleConfiguration.  # noqa: E501


        :return: The locked of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this ModuleConfiguration.


        :param locked: The locked of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def modified(self):
        """Gets the modified of this ModuleConfiguration.  # noqa: E501


        :return: The modified of this ModuleConfiguration.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this ModuleConfiguration.


        :param modified: The modified of this ModuleConfiguration.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this ModuleConfiguration.  # noqa: E501


        :return: The name of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModuleConfiguration.


        :param name: The name of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def path(self):
        """Gets the path of this ModuleConfiguration.  # noqa: E501


        :return: The path of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ModuleConfiguration.


        :param path: The path of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def prev_name(self):
        """Gets the prev_name of this ModuleConfiguration.  # noqa: E501


        :return: The prev_name of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this ModuleConfiguration.


        :param prev_name: The prev_name of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def propagation_labels(self):
        """Gets the propagation_labels of this ModuleConfiguration.  # noqa: E501


        :return: The propagation_labels of this ModuleConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._propagation_labels

    @propagation_labels.setter
    def propagation_labels(self, propagation_labels):
        """Sets the propagation_labels of this ModuleConfiguration.


        :param propagation_labels: The propagation_labels of this ModuleConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._propagation_labels = propagation_labels

    @property
    def readonly(self):
        """Gets the readonly of this ModuleConfiguration.  # noqa: E501


        :return: The readonly of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._readonly

    @readonly.setter
    def readonly(self, readonly):
        """Sets the readonly of this ModuleConfiguration.


        :param readonly: The readonly of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._readonly = readonly

    @property
    def script_not_visible(self):
        """Gets the script_not_visible of this ModuleConfiguration.  # noqa: E501


        :return: The script_not_visible of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._script_not_visible

    @script_not_visible.setter
    def script_not_visible(self, script_not_visible):
        """Sets the script_not_visible of this ModuleConfiguration.


        :param script_not_visible: The script_not_visible of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._script_not_visible = script_not_visible

    @property
    def should_commit(self):
        """Gets the should_commit of this ModuleConfiguration.  # noqa: E501


        :return: The should_commit of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this ModuleConfiguration.


        :param should_commit: The should_commit of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this ModuleConfiguration.  # noqa: E501


        :return: The sort_values of this ModuleConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this ModuleConfiguration.


        :param sort_values: The sort_values of this ModuleConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def source_module_id(self):
        """Gets the source_module_id of this ModuleConfiguration.  # noqa: E501


        :return: The source_module_id of this ModuleConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._source_module_id

    @source_module_id.setter
    def source_module_id(self, source_module_id):
        """Sets the source_module_id of this ModuleConfiguration.


        :param source_module_id: The source_module_id of this ModuleConfiguration.  # noqa: E501
        :type: str
        """

        self._source_module_id = source_module_id

    @property
    def system(self):
        """Gets the system of this ModuleConfiguration.  # noqa: E501


        :return: The system of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this ModuleConfiguration.


        :param system: The system of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this ModuleConfiguration.  # noqa: E501


        :return: The vc_should_ignore of this ModuleConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this ModuleConfiguration.


        :param vc_should_ignore: The vc_should_ignore of this ModuleConfiguration.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this ModuleConfiguration.  # noqa: E501


        :return: The version of this ModuleConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ModuleConfiguration.


        :param version: The version of this ModuleConfiguration.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModuleConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModuleConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
